@@ -1,6 +1,5 @@
 require 'bundler/setup'
-require 'minitest/autorun'
-require 'minitest/rg'
+require 'maxitest/autorun'
 
 $LOAD_PATH.unshift File.expand_path("../../lib", __FILE__)
 require_relative '../lib/rchardet'
